	SUBROUTINE PARCOR(PHI,T)
	IMPLICIT REAL*8(A-H,O-Z)

C  CALCULATES PARTICLE-PARTICLE ANGULAR CORRELATIONS
C  CONVENTIONS OF FINKEL ET.AL.,PHYS.REV.C19(1979)1782 ARE FOLLOWED
c Nov-2000 M.Yosoi   Rev. for IBM-xlf

	INCLUDE 'ANGCOR.INC'
	REAL AN1(MAX_EXP),PH1(MAX_EXP),C1(MAX_EXP),EC1(MAX_EXP),
     1  TH1(MAX_EXP)
	COMMON /CROSS/   N1, AN1, PH1, C1,EC1, TH1
	COMMON /FISSION/ KA, KB1, XKA, XKB, XKJ
        REAL TI(INTER_CH),SQRS(INTER_CH-1)
        COMMON /INTCRO/  NCH, TI, SQRS
	DIMENSION PH2(MAX_EXP)
	WRITE(LUNOUT,100)
	IF(ICO(1).EQ.1.OR.ICO(1).EQ.2) THEN
	  LMAX=LDEC(1,1)+1
	  DO 1 J=1,NCH
	  WRITE(LUNOUT,101) J
	  WRITE(LUNOUT,102) DELTA(J,1),DELTA(J,2),DELTA(J,3)
	  DO 1 I=1,NLDEC(J)
	  LMAX=MAX0(LMAX,LDEC(J,I)+1)
1	  CONTINUE
	ENDIF
	IF (N1 .LE. 0 ) GO TO 2
	DO 3 I=1,N1
	PH2(I) = PH1(I)/57.295779
	IF(ICO(1).EQ.3) THEN
	  CALL FISCOR(AN1(I),PH2(I),T,TH1(I))
	ELSE
	  CALL PARP(AN1(I),PH2(I),LMAX,T,TH1(I))
	ENDIF
3	CONTINUE
2	CONTINUE
	IF(ICO(8) .EQ.0) THEN
	  ANGP=-DANGP
	  DO 4 NP=1,NANGP
	  ANGP=ANGP+DANGP
	  IF(ICO(1).EQ.3) THEN
	    CALL FISCOR(ANGP,PHI,T,SIGMA)
	  ELSE
	    CALL PARP(ANGP,PHI,LMAX,T,SIGMA)
	  ENDIF
	  SIG(NP)=SIGMA
4	  CONTINUE
	ENDIF
	RETURN
100	FORMAT(1H ,////,'   PARCOR ENTERED ')
101	FORMAT(1H ,'  INTERMEDIATE STATE =',I3)
102	FORMAT(1H ,' DELTA(1) =',F9.4,'   DELTA(2) =',F9.4,
     1  '   DELTA(3) =',F9.4)
	END
