
	FUNCTION RK(XL1,XL2,XJ1,XJ2,XK)
	IMPLICIT REAL*8(A-H,O-Z)

C  CALCULATES THE GAMMA RAY MIXING COEFFICIENTS

	N=NINT(1.+XJ1-XJ2+XL2-XL1-XK)
	RK=PAR(N)*SQRT((2.*XJ1+1.)*(2.*XL1+1.)*(2.*XL2+1.))
	RK=RK*CG(XL1,1.D0,XL2,-1.D0,XK,0.D0)*W(XJ1,XJ1,XL1,XL2,XK,XJ2)
	RETURN
	END
