	SUBROUTINE SIGMA(ANGP,PHI,KL,SIG1)
	IMPLICIT REAL*8(A-H,O-Z)

	INCLUDE 'ANGCOR.INC'
	COMMON /EXTRA/   ZW(MAX_LG), RKK(MAX_LG)

	COMPLEX*16 C
	SIG1=0.
	CALL PLM(ANGP,KL,KL)
	KK=-2
	XK=-2.
	DO 1 K=1,KL,2
	KK=KK+2
	XK=XK+2.
	IQ=2*K-1
	DO 1 KQ=1,IQ
	MQ=KQ-K
	KMQ=KK*KK+KK+MQ+1
	IF (KK.EQ.0) THEN
	  SIG1 = SIG1 + RHO(KMQ)*C(KK,MQ,PHI)
	ELSE
	  SIG1 = SIG1 +RHO(KMQ)*C(KK,MQ,PHI)*RKK(KK/2)*ZW(KK/2)
	ENDIF

1	CONTINUE
	RETURN
	END
