	SUBROUTINE PLOT
	IMPLICIT REAL*8(A-H,O-Z)
c Nov-2000 M.Yosoi   Rev. for IBM-xlf

	INCLUDE 'ANGCOR.INC'

	DIMENSION ARRAY(26),STAR(4),STAR0(4),STAR1(4),STAR2(4)
	DATA BAR,BLNK,AXIS,PLUS,PLAX/4H|   ,4H    ,4H----,4H+   ,4H+---/
	DATA STAR /4H*   ,4H *  ,4H  * ,4H   */
	DATA STAR0/4H*---,4H-*--,4H--*-,4H---*/
	DATA STAR1/4H*   ,4H|*  ,4H| * ,4H|  */
	DATA STAR2/4H*---,4H+*--,4H+-*-,4H+--*/
	DATA ARRAY/26*4H    /
	N=0
	NN1=1
	IF(NPLOT.EQ.0)NPLOT=1
	DO 1 I=1,NANGP
	ISIG=SIG(I)+1.
1	NN1=MAX0(NN1,ISIG)
	NN1=NN1*NPLOT
	WRITE(LUNOUT,100) N,NN1
	B = 0.
	BASE = 0.
	IWORD=1
	XN=100./DFLOAT(NN1)
	DO 2 I=1,NANGP
	IF (I.EQ.1.OR.I.EQ.NANGP) THEN
	  ARRAY(1)=PLAX
	  ARRAY(26)=PLUS
	  DO 3 K=2,25
3	  ARRAY(K) = AXIS
	ELSE
	  ARRAY(1)=BAR
	  ARRAY(26)=BAR
	ENDIF
	IF( SIG(I).LT.BASE )  GO TO 4
	ARG = XN*SIG(I)
	J = NINT(ARG)
	IWORD=J/4 + 1
	IKAR=J - 4*(IWORD-1)
	IF (I.EQ.1.OR.I.EQ.NANGP) THEN
	  IF (IWORD.NE.1) THEN
	    ARRAY(IWORD)=STAR0(IKAR+1)
	  ELSE
	    ARRAY(1)=STAR2(IKAR+1)
	  ENDIF
	ELSE
	  IF(IWORD.NE.1) THEN
	    ARRAY(IWORD)=STAR(IKAR+1)
	  ELSE
	    ARRAY(1)=STAR1(IKAR+1)
	  ENDIF
	ENDIF
4	CONTINUE
	WRITE(LUNOUT,101) B,SIG(I),ARRAY
	ARRAY(IWORD)=BLNK
	IF(I.EQ.1) THEN
	  DO 5 K=2,25
5	  ARRAY(K)=BLNK
	ENDIF
	B = B + DANGP
2	CONTINUE
	RETURN

C  STAR (*) CARRIAGE CONTROL PRINTS OVER PAGE EDGE.

100	FORMAT(1H0,21X,4X,I3,97X,I3/4X,5HTHETA,6X,
     1  11HPROBABILITY,2X,1HI,99X,1HI)
101	FORMAT(1H*,F9.4,E14.4,4X,26A4)
	END
