C ??? tbs


	SUBROUTINE CIO_COPY_I (SRC, DST)
	IMPLICIT NONE
	INTEGER SRC, DST
	DST = SRC
	END

	SUBROUTINE CIO_COPY_F (SRC, DST)
	IMPLICIT NONE
	REAL*4 SRC, DST
	DST = SRC
	END

	SUBROUTINE CIO_COPY_D (SRC, DST)
	IMPLICIT NONE
	REAL*8 SRC, DST
	DST = SRC
	END

	SUBROUTINE CIO_COPY_L (SRC, DST)
	IMPLICIT NONE
	LOGICAL SRC, DST
	DST = SRC
	END

	SUBROUTINE CIO_COPY_B (SRC, DST)
	IMPLICIT NONE
	LOGICAL*1 SRC, DST
	DST = SRC
	END

	SUBROUTINE CIO_COPY_S (SRC, SRCLEN, DST)
	IMPLICIT NONE
	INTEGER*1     SRC(*)	! passed by reference
	CHARACTER*(*) DST		! passed by descriptor ???
	INTEGER SRCLEN

	INTEGER K

	DO K = 1, LEN(DST)
		IF (K.LE.SRCLEN) THEN
			DST(K:K) = CHAR(SRC(K))
		ELSE
			DST(K:K) = ' '
		ENDIF
	ENDDO
	END
