	SUBROUTINE FISCOR(ANGP,PHI,T,SIGMA)
	IMPLICIT REAL*8(A-H,O-Z)
c Nov-2000 M.Yosoi   Rev. for IBM-xlf

	INCLUDE 'ANGCOR.INC'
	COMPLEX*16 FP,AI,X
	COMMON /FISSION/ KA, KB1, XKA, XKB, XKJ

	SIG1=0.
	XJBB1=FLOAT(LF2(1))
	CALL DJMK(ANGP,PHI,0.D0,JB(1),KB1,RHO(1))
	MA=-JA
	DO 1 M1=1,LF1
	XMA=FLOAT(MA)/2.
	IMSB=-ISB
	DO 2 MS=1,JS
	IMSA=-ISA
	DO 3 MR=1,JR
	X=(0.,0.)
	MT=0
	MB=-JB(1)
	DO 4 M21=1,LF2(1)
	XMB=FLOAT(MB)/2.
	MJ=MB-MA
	XMJ=XMB-XMA
	MX=IABS(MJ)/2+1
	IND=0
	AI=(0.,0.)
	IF(ICO(5).EQ.1) THEN
	  JIND=(M1-1)*M21+M21+MT
	  AI=SUM(MS,MR,JIND)
	ELSE
	  DO 5 LSJ=1,NLTR
	  IF(MX.GT.JTR(LSJ)/2+1) GO TO 6
	  XJ=FLOAT(JTR(LSJ))/2.
	  IND1=(MJ+JTR(LSJ))/2+1
	  FP=SUM(MS,MR,IND+IND1)
	  AI=AI+CG(XJA,XMA,XJ,XMJ,XJB(1),XMB)*CG(XJA,XKA,XJ,XKJ,XJB(1)
     1  ,XKB)*FP*SQRT(DFLOAT((JTR(LSJ)+1)*LF1)/XJBB1)
6	  IND=IND+JTR(LSJ)+1
5	  CONTINUE
	ENDIF
	X=X+AI*RHO(M21)
	MB=MB+2
4	CONTINUE
	SIG1=SIG1+DREAL(X)**2+DIMAG(X)**2
	IMSA=IMSA+2
3	CONTINUE
	IMSB=IMSB+2
2	CONTINUE
	MA=MA+2
1	CONTINUE
	SIG1=SIG1*XJBB1/2.
	SIGMA=SIG1/T
	RETURN
	END
