	SUBROUTINE CIOQPU
C++
C TITLE:  CIOQPU
C FACILITY:  CIO  - conversational I/O package.
C ABSTRACT: Purge qualifier definition list.
C AUTHOR: Peter A. Kroon, KVI, Groningen, NL.
C CREATION DATE: 13-may-1981
C MODIFIED BY:
C FUNCTIONAL DESCRIPTION:
C	Remove all qualifier definitions.
C CALLING SEQUENCE:
C	CALL CIOQPU
C--
	INCLUDE		'ciocom.inc'
	Q_NR = 0

	RETURN
	END
