	COMPLEX FUNCTION C*16(L,M,PHI)
	IMPLICIT REAL*8(A-H,O-Z)

C   CALCULATES RENORMALIZED SPHERICAL HARMONICS

	INCLUDE 'ANGCOR.INC'

	PHAS=PAR(M)
	IF(M.LT.0) PHAS=1.
	P=M*PHI
	M1=IABS(M)
	C = (0.,0.)
	IF(M1.GT.L) RETURN
	CALL FACTOR(L,M1,F)
	M1=M1+1
	L1=L+1
	C=PHAS*DCMPLX(COS(P),SIN(P))*PL(L1,M1)/SQRT(F)
	RETURN
	END
